@@ -1,11 +1,11 @@
 __title__ = 'datclass'
 __author__ = 'foyoux'
-__version__ = '0.0.2'
-__all__ = ['DatClass', 'main']
+__version__ = '0.0.4'
+__all__ = ['main', 'Nested', 'Extra']
 
 import argparse
 
-from datclass.datclass import DatClass
+from datclass.datclass import Nested, Extra
 
 
 def main():
